@@ -6,6 +6,7 @@ from sdk.device.configuration.base_config import BaseConfig, InvalidConfiguratio
 
 DT_VALUE_NOT_VALID = "dt must be larger than 0. Not {}."
 PRECISION_NOT_VALID = "Precision {} not valid. Must be one of 'low', 'normal', 'high'"
+MAX_BOND_DIM_NOT_VALID = "Max bond dimension {} must be larger than 0. Not {}."
 
 
 @dataclass
@@ -13,12 +14,12 @@ class EmuTNConfig(BaseConfig):
     """Configuration for the EmuTN device type.
 
     Args:
-        dt (float): The time step of the simulation. Defaults to 0.1.
+        dt (float): The time step in nanoseconds of the simulation. Defaults to 10.0.
         precision (str): The precision of the simulation. Defaults to "normal".
         max_bond_dim (int): The maximum bond dimension of the Matrix Product State (MPS). Defaults to 500.
     """
 
-    dt: float = 0.1
+    dt: float = 10.0
     precision: str = "normal"
     max_bond_dim: int = 500
 
@@ -27,4 +28,6 @@ class EmuTNConfig(BaseConfig):
             raise InvalidConfiguration(DT_VALUE_NOT_VALID.format(self.dt))
         if self.precision not in ["low", "normal", "high"]:
             raise InvalidConfiguration(PRECISION_NOT_VALID.format(self.precision))
+        if self.max_bond_dim <= 0:
+            raise InvalidConfiguration(MAX_BOND_DIM_NOT_VALID.format(self.max_bond_dim))
         super()._validate()
